@@ -2,16 +2,19 @@
 # Utilities
 #
 
-enquote <- function(x) as.call(list(as.name("quote"), x))
-
 docall <- function(fun, args) {
     if ((is.character(fun) && length(fun) == 1) || is.name(fun))
         fun <- get(as.character(fun), env = .GlobalEnv, mode = "function")
     do.call("fun", lapply(args, enquote))
 }
 
-if (! exists("emptyenv"))
-    emptyenv <- function() NULL
+shQuoteIfNeeded <- function(p) {
+    if (length(grep("[[:space:]]", p)) == 0)
+        p
+    else if (.Platform$OS.type == "windows")
+        shQuote(p)
+    else stop("file names with spaces do not work properly on this platform")
+}
 
 
 #
@@ -314,6 +317,7 @@ dynamicClusterApply <- function(cl, fun, n, argfun) {
 }
 
 clusterApplyLB <- function(cl, x, fun, ...) {
+    ## **** this closure is sending all of x to all nodes
     argfun <- function(i) c(list(x[[i]]), list(...))
     dynamicClusterApply(cl, fun, length(x), argfun)
 }
@@ -333,6 +337,7 @@ clusterMap <- function (cl, fun, ..., MoreArgs = NULL, RECYCLE = TRUE) {
                 length = max(n))
     }
     else vlen = min(n)
+    ## **** this closure is sending all of ... to all nodes
     argfun <- function(i) c(lapply(args, function(x) x[[i]]), MoreArgs)
     staticClusterApply(cl, fun, vlen, argfun)
 }
